import lib from 'lib'
import axios from 'axios'
import {Indicator, Toast, MessageBox} from 'mint-ui';

var Appid = lib.getParam('dwAppId');
var uid = lib.getParam('uid');
var openid = lib.getParam('openid');
var traceNo;  //小游戏支付交易的订单号
var checkMaxTime = 5000;
var checkDuringTime = 500;
var checkStartTime = 0;

var pay = {
    async handlePay(productId,productCount=1) {

        if(!lib.checkWXAgent()) {
            MessageBox("提示", "请在微信客户端打开");
            return;
        }

        let configDone = await this.configWX();
        
        if(!configDone) {
            MessageBox('提示', '未知错误，请重试');
            return;
        };

        Indicator.open('正在创建订单...');
        axios.post(`${lib.apiUrl}/order/proxyPay`, {
            dwAppId: Appid,
            uid: uid,
            openid: openid,
            productId: productId,
            count: productCount
        }).then(({data}) => {
            Indicator.close();

            if(!data.data) {
                MessageBox("提示", data.msg)
                return;
            }

            let pData = data.data.platformData;
            traceNo = data.data.traceNo;
            
            setTimeout(()=>{
                wx.chooseWXPay({
                    timestamp: pData.timestamp,
                    nonceStr: pData.nonceStr,
                    package: pData.package,
                    signType: pData.signType,
                    paySign: pData.paySign,
                    success (res) {
                        // 支付成功后的回调函数
                        Indicator.close();
                        Indicator.open('游戏充值中...');
                        pay.checkOrder();
                    },cancel : function(res) {
                        Indicator.close();
                    },
                    fail : function(res) {
                        Indicator.close();

                    }
                })
            },100)

        })
    },
    configWX() {
        return new Promise((resolve, reject) => {
            axios.get(`${lib.apiUrl}/auth/jsSign`, {
                    params: {
                        url: location.href
                    }
                }).then(({data}) => {
                    wx.config({
                        debug: false,
                        appId: 'wxc137e1554d993f74',
                        nonceStr: data.data.nonceStr,
                        signature: data.data.signature,
                        timestamp: data.data.timestamp,
                        jsApiList: [
                            "chooseWXPay"
                        ]
                    });

                    wx.error(function(res){
                        MessageBox("提示", JSON.stringify(res))
                    });

                    wx.ready(() => {
                        resolve(true)
                    })
                }).catch(({data}) => {
                    MessageBox("提示", data.msg)
                    reject(false)
                })
            })
    },
    checkOrder(){
        axios.get(`${lib.apiUrl}/order/state`, {
                params: {
                    dwAppId: Appid,
                    tradeNo: traceNo
                }
            }).then(({data}) => {
                //-1:支付失败;0:支付中;1:支付成功;
                data.data.state = data.data.state *1;
                switch(data.data.state){
                    case -1:
                        Indicator.close();
                        MessageBox("提示", "商品购买失败")
                        break;
                    case 0:
                        if(checkStartTime>checkMaxTime) {
                            Indicator.close();
                            MessageBox("提示", "商品购买结果请进游戏确认")
                            return;
                        }
                        setTimeout(()=>{
                            checkStartTime += checkDuringTime;
                            pay.checkOrder();
                        },checkDuringTime)
                        break;
                    case 1:
                        Indicator.close();
                        MessageBox("提示", "商品购买成功")
                        break;
                }
            }).catch(({data}) => {
                Indicator.close();
                MessageBox("提示", data.msg)
            })
    }
}

export default pay;